@@ -82,7 +82,7 @@ function goTo2NFStep1() {
             $("#mainContent #extra").html(data.extra);
             $("#mainContent #newCols").html('');
             if (data.subText !== '') {
-                $('.tblFooters').html('<input type="submit" value="' + PMA_messages.strDone + '" onclick="processDependencies(\'' + data.primary_key + '\');">');
+                $('.tblFooters').html('<input type="submit" value="' + PMA_messages.strDone + '" onclick="processDependencies(\'' + escapeJsString(escapeHtml(data.primary_key)) + '\');">');
             } else {
                 if (normalizeto === '3nf') {
                     $("#mainContent #newCols").html(PMA_messages.strToNextStep);
@@ -102,7 +102,7 @@ function goToFinish1NF()
     }
     $("#mainContent legend").html(PMA_messages.strEndStep);
     $("#mainContent h4").html(
-        "<h3>" + PMA_sprintf(PMA_messages.strFinishMsg, PMA_commonParams.get('table')) + "</h3>"
+        "<h3>" + PMA_sprintf(PMA_messages.strFinishMsg, escapeHtml(PMA_commonParams.get('table'))) + "</h3>"
     );
     $("#mainContent p").html('');
     $("#mainContent #extra").html('');
@@ -128,7 +128,7 @@ function goToStep4()
             $("#mainContent #newCols").html('');
             $('.tblFooters').html('');
             for(var pk in primary_key) {
-                $("#extra input[value='" + primary_key[pk] + "']").attr("disabled","disabled");
+                $("#extra input[value='" + escapeJsString(primary_key[pk]) + "']").attr("disabled","disabled");
             }
         }
     );
@@ -151,9 +151,9 @@ function goToStep3()
             $("#mainContent #extra").html(data.extra);
             $("#mainContent #newCols").html('');
             $('.tblFooters').html('');
-            primary_key = $.parseJSON(data.primary_key);
+            primary_key = JSON.parse(data.primary_key);
             for(var pk in primary_key) {
-                $("#extra input[value='" + primary_key[pk] + "']").attr("disabled","disabled");
+                $("#extra input[value='" + escapeJsString(primary_key[pk]) + "']").attr("disabled","disabled");
             }
         }
     );
@@ -209,7 +209,7 @@ function goTo2NFFinish(pd)
             "newTablesName":JSON.stringify(tables),
             "createNewTables2NF":1};
     $.ajax({
-            type: "GET",
+            type: "POST",
             url: "normalization.php",
             data: datastring,
             async:false,
@@ -254,7 +254,7 @@ function goTo3NFFinish(newTables)
             "newTables":JSON.stringify(newTables),
             "createNewTables3NF":1};
     $.ajax({
-            type: "GET",
+            type: "POST",
             url: "normalization.php",
             data: datastring,
             async:false,
@@ -303,7 +303,7 @@ function goTo2NFStep2(pd, primary_key)
             "pd": JSON.stringify(pd),
             "getNewTables2NF":1};
         $.ajax({
-            type: "GET",
+            type: "POST",
             url: "normalization.php",
             data: datastring,
             async:false,
@@ -352,12 +352,12 @@ function goTo3NFStep2(pd, tablesTds)
             "pd": JSON.stringify(pd),
             "getNewTables3NF":1};
         $.ajax({
-            type: "GET",
+            type: "POST",
             url: "normalization.php",
             data: datastring,
             async:false,
             success: function(data) {
-                data_parsed = $.parseJSON(data.message);
+                data_parsed = data;
                 if (data.success === true) {
                     extra += data_parsed.html;
                 } else {
@@ -393,7 +393,7 @@ function processDependencies(primary_key, isTransitive)
             tablesTds[tblname].push(primary_key);
         }
         var form_id = $(this).attr('id');
-        $('#' + form_id + ' input[type=checkbox]:not(:checked)').removeAttr('checked');
+        $('#' + form_id + ' input[type=checkbox]:not(:checked)').prop('checked', false);
         dependsOn = '';
         $('#' + form_id + ' input[type=checkbox]:checked').each(function(){
             dependsOn += $(this).val() + ', ';
@@ -526,7 +526,7 @@ AJAX.registerOnload('normalization.js', function() {
         datastring += "&ajax_request=1&do_save_data=1&field_where=last";
         $.post("tbl_addfield.php", datastring, function(data) {
             if (data.success) {
-                $.get(
+                $.post(
                     "sql.php",
                     {
                         "token": PMA_commonParams.get('token'),
@@ -604,7 +604,7 @@ AJAX.registerOnload('normalization.js', function() {
             dropQuery += 'DROP `' + $(this).val() + '`, ';
         });
         dropQuery = dropQuery.slice(0, -2);
-        $.get(
+        $.post(
             "sql.php",
             {
                 "token": PMA_commonParams.get('token'),
@@ -637,8 +637,8 @@ AJAX.registerOnload('normalization.js', function() {
                 '( ' + escapeHtml(primary_key.toString()) + ', <input type="text" name="repeatGroupColumn" placeholder="' + PMA_messages.strNewColumnPlaceholder + '" value="' + escapeHtml(newColName) + '">)' +
                 '</ol>';
             $("#newCols").html(confirmStr);
-            $('.tblFooters').html('<input type="submit" value="' + PMA_messages.strCancel + '" onclick="$(\'#newCols\').html(\'\');$(\'#extra input[type=checkbox]\').removeAttr(\'checked\')"/>' +
-                '<input type="submit" value="' + PMA_messages.strGo + '" onclick="moveRepeatingGroup(\'' + repeatingCols + '\')"/>');
+            $('.tblFooters').html('<input type="submit" value="' + PMA_messages.strCancel + '" onclick="$(\'#newCols\').html(\'\');$(\'#extra input[type=checkbox]\').prop(\'checked\', false)"/>' +
+                '<input type="submit" value="' + PMA_messages.strGo + '" onclick="moveRepeatingGroup(\'' + escapeJsString(escapeHtml(repeatingCols)) + '\')"/>');
         }
     });
     $("#mainContent p").on("click", "#createPrimaryKey", function(event) {
