@@ -7,6 +7,7 @@
  */
 
 use PMA\libraries\VersionInformation;
+use PMA\libraries\Sanitize;
 
 if (!defined('PHPMYADMIN')) {
     exit;
@@ -79,23 +80,18 @@ function PMA_messagesEnd()
  */
 function PMA_messagesShowHtml()
 {
-    $old_ids = array();
     foreach ($_SESSION['messages'] as $type => $messages) {
         foreach ($messages as $id => $msg) {
-            echo '<div class="' , $type , '" id="' , $id , '">'
+            if (! $msg['fresh'] && $type != 'error') {
+                $extra = ' hiddenmessage';
+            } else {
+                $extra = '';
+            }
+            echo '<div class="' , $type, $extra , '" id="' , $id , '">'
                 , '<h4>' , $msg['title'] , '</h4>'
                 , $msg['message'] , '</div>';
-            if (!$msg['fresh'] && $type != 'error') {
-                $old_ids[] = $id;
-            }
         }
     }
-
-    echo "\n" , '<script type="text/javascript">';
-    foreach ($old_ids as $id) {
-        echo "\nhiddenMessages.push('$id');";
-    }
-    echo "\n</script>\n";
 }
 
 /**
@@ -174,7 +170,7 @@ function PMA_versionCheck()
                 'notice',
                 $message_id,
                 __('Version check'),
-                PMA_sanitize(sprintf(__('You are using Git version, run [kbd]git pull[/kbd] :-)[br]The latest stable version is %s, released on %s.'), $version, $date))
+                Sanitize::sanitize(sprintf(__('You are using Git version, run [kbd]git pull[/kbd] :-)[br]The latest stable version is %s, released on %s.'), $version, $date))
             );
         } else {
             PMA_messagesSet(
@@ -186,28 +182,3 @@ function PMA_versionCheck()
         }
     }
 }
-
-/**
- * Checks whether config file is readable/writable
- *
- * @param bool &$is_readable whether the file is readable
- * @param bool &$is_writable whether the file is writable
- * @param bool &$file_exists whether the file exists
- *
- * @return void
- */
-function PMA_checkConfigRw(&$is_readable, &$is_writable, &$file_exists)
-{
-    $file_path = $GLOBALS['ConfigFile']->getFilePath();
-    $file_dir = dirname($file_path);
-    $is_readable = true;
-    $is_writable = @is_dir($file_dir);
-    if (SETUP_DIR_WRITABLE) {
-        $is_writable = $is_writable && @is_writable($file_dir);
-    }
-    $file_exists = file_exists($file_path);
-    if ($file_exists) {
-        $is_readable = is_readable($file_path);
-        $is_writable = $is_writable && @is_writable($file_path);
-    }
-}
