@@ -1,17 +1,21 @@
 <?php
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
- * A caching proxy for retrieving version information from phpmyadmin.net
+ * A caching proxy for retrieving version information from https://www.phpmyadmin.net/
  *
  * @package PhpMyAdmin
  */
 
 // Sets up the session
 use PMA\libraries\VersionInformation;
+use PMA\libraries\Response;
+
+$_GET['ajax_request'] = 'true';
 
-define('PMA_MINIMUM_COMMON', true);
 require_once 'libraries/common.inc.php';
-require_once 'libraries/VersionInformation.php';
+
+// Disabling standard response.
+Response::getInstance()->disable();
 
 // Always send the correct headers
 PMA_headerJSON();
